import json

from orchestrator.targets import Target
from orchestrator.types import State
from orchestrator.utils.json import json_dumps
from orchestrator.workflow import StepList, init, workflow, done, step
from orchestrator.workflows.steps import store_process_subscription, unsync, resync

from gso.services.provisioning_proxy import pp_interaction, execute_playbook
from gso.workflows.router.create_router import verify_ipam_loopback
from products import Router


@step("Validate router configuration")
def validate_router_config(subscription: Router, callback_route: str) -> None:
    extra_vars = {"wfo_router_json": json.loads(json_dumps(subscription)), "verb": "validate"}

    execute_playbook(
        playbook_name="base_config.yaml",
        callback_route=callback_route,
        inventory=subscription.router.router_fqdn,
        extra_vars=extra_vars
    )


@workflow("Validate router configuration", target=Target.SYSTEM)
def validate_router() -> StepList:
    """Validate an existing, active Router subscription.

    * Run an Ansible playbook to verify the configuration is intact.
    * Verify that the loopback interface is correctly configured in IPAM.
    """
    return (
        init
        >> store_process_subscription(Target.SYSTEM)
        >> unsync
        >> pp_interaction(validate_router_config)
        >> verify_ipam_loopback
        >> resync
        >> done
    )
